@@ -21,7 +21,7 @@
 #ifndef LMS_F32_PLUGIN_H_
 #define LMS_F32_PLUGIN_H_
 
-#include <kparts/plugin.h>
+#include <tdeparts/plugin.h>
 
 /**
  * A plugin wrapper around the LMS F32 colour space strategy.
@@ -29,7 +29,7 @@
 class LMSF32Plugin : public KParts::Plugin
 {
     Q_OBJECT
-  TQ_OBJECT
+  
 public:
     LMSF32Plugin(TQObject *parent, const char *name, const TQStringList &);
     virtual ~LMSF32Plugin();
