@@ -25,10 +25,10 @@
 #include <tqwidget.h>
 #include <tqlayout.h>
 
-#include <kaction.h>
+#include <tdeaction.h>
 #include <kdebug.h>
 #include <kcommand.h>
-#include <klocale.h>
+#include <tdelocale.h>
 
 #include <kis_button_press_event.h>
 #include <kis_button_release_event.h>
@@ -465,19 +465,19 @@ void KisToolPerspectiveGrid::drawGrid()
 }
 
 
-void KisToolPerspectiveGrid::setup(KActionCollection *collection)
+void KisToolPerspectiveGrid::setup(TDEActionCollection *collection)
 {
-    m_action = static_cast<KRadioAction *>(collection->action(name()));
+    m_action = static_cast<TDERadioAction *>(collection->action(name()));
 
     if (m_action == 0) {
-        m_action = new KRadioAction(i18n("&Perspective Grid"),
+        m_action = new TDERadioAction(i18n("&Perspective Grid"),
                                     "tool_perspectivegrid" ,
                         0,
                         this,
                         TQT_SLOT(activate()),
                         collection,
                         name());
-        Q_CHECK_PTR(m_action);
+        TQ_CHECK_PTR(m_action);
         m_action->setExclusiveGroup("tools");
         m_action->setToolTip(i18n("Edit the perspective grid"));
         m_ownAction = true;
