@@ -19,7 +19,7 @@
 #ifndef TOOL_PERSPECTIVE_TRANSFORM_H_
 #define TOOL_PERSPECTIVE_TRANSFORM_H_
 
-#include <kparts/plugin.h>
+#include <tdeparts/plugin.h>
 
 class KisView;
 
@@ -29,7 +29,7 @@ class KisView;
 class ToolPerspectiveTransform : public KParts::Plugin
 {
     Q_OBJECT
-  TQ_OBJECT
+  
 public:
     ToolPerspectiveTransform(TQObject *parent, const char *name, const TQStringList &);
     virtual ~ToolPerspectiveTransform();
