@@ -37,13 +37,13 @@
 #include <tqcheckbox.h>
 
 #include <kdebug.h>
-#include <kglobal.h>
-#include <kpopupmenu.h>
-#include <kmessagebox.h>
+#include <tdeglobal.h>
+#include <tdepopupmenu.h>
+#include <tdemessagebox.h>
 #include <kpushbutton.h>
 #include <kiconloader.h>
 #include <kicontheme.h>
-#include <klocale.h>
+#include <tdelocale.h>
 
 #include <KoPartSelectAction.h>
 
@@ -82,17 +82,17 @@ KisLayerBox::KisLayerBox(KisCanvasSubject *subject, TQWidget *parent, const char
 
     TQToolTip::add(m_lst->bnProperties, i18n("Properties for layer"));
 
-    KIconLoader il( "chalk" );
+    TDEIconLoader il( "chalk" );
 
     list()->setPreviewsShown(true);
 
     list()->setFoldersCanBeActive(true);
 
-    list()->addProperty("visible", i18n("Visible"), loadPixmap("visible.png", il, KIcon::SizeSmallMedium),
-                                                      loadPixmap("novisible.png", il, KIcon::SizeSmallMedium), true);
+    list()->addProperty("visible", i18n("Visible"), loadPixmap("visible.png", il, TDEIcon::SizeSmallMedium),
+                                                      loadPixmap("novisible.png", il, TDEIcon::SizeSmallMedium), true);
 
-    list()->addProperty("locked", i18n("Locked"), loadPixmap("locked.png", il, KIcon::SizeSmallMedium),
-                                                    loadPixmap("unlocked.png", il, KIcon::SizeSmallMedium));
+    list()->addProperty("locked", i18n("Locked"), loadPixmap("locked.png", il, TDEIcon::SizeSmallMedium),
+                                                    loadPixmap("unlocked.png", il, TDEIcon::SizeSmallMedium));
 
 
     connect(list()->contextMenu(), TQT_SIGNAL(aboutToShow()), TQT_SLOT(slotAboutToShow()));
@@ -117,10 +117,10 @@ KisLayerBox::KisLayerBox(KisCanvasSubject *subject, TQWidget *parent, const char
     connect(list(), TQT_SIGNAL(requestLayerProperties(LayerItem*)),
                     TQT_SLOT(slotRequestLayerProperties(LayerItem*)));
 
-    m_newLayerMenu = new KPopupMenu(this);
+    m_newLayerMenu = new TDEPopupMenu(this);
     m_lst->bnAdd->setPopup(m_newLayerMenu);
     m_lst->bnAdd->setPopupDelay(1);
-    m_newLayerMenu->insertItem( SmallIconSet( "filenew" ), i18n( "&New Layer..." ), PAINT_LAYER );
+    m_newLayerMenu->insertItem( SmallIconSet( "document-new" ), i18n( "&New Layer..." ), PAINT_LAYER );
     m_newLayerMenu->insertItem( SmallIconSet( "folder" ), i18n( "New &Group Layer..." ), GROUP_LAYER );
     m_newLayerMenu->insertItem( SmallIconSet( "tool_filter" ), i18n( "New &Adjustment Layer..." ), ADJUSTMENT_LAYER );
     m_partLayerAction = new KoPartSelectAction( i18n( "New &Object Layer" ), "gear", TQT_TQOBJECT(this) );
@@ -588,10 +588,10 @@ void KisLayerBox::setUpdatesAndSignalsEnabled(bool enable)
 }
 
 
-TQPixmap KisLayerBox::loadPixmap(const TQString& filename, const KIconLoader&
+TQPixmap KisLayerBox::loadPixmap(const TQString& filename, const TDEIconLoader&
                                     il, int size)
 {
-    TQPixmap pixmap = il.loadIcon(filename, KIcon::NoGroup, size);
+    TQPixmap pixmap = il.loadIcon(filename, TDEIcon::NoGroup, size);
 
     if (pixmap.isNull())
         KMessageBox::error(0, i18n("Cannot find %1").arg(filename),
