@@ -40,14 +40,14 @@
 #include <tqprogressdialog.h>
 #include <tqtimer.h>
 
-#include <kglobal.h>
-#include <kconfig.h>
+#include <tdeglobal.h>
+#include <tdeconfig.h>
 #include <knuminput.h>
 #include <kgenericfactory.h>
 #include <kdialogbase.h>
 #include <kdialog.h>
-#include <kmessagebox.h>
-#include <klocale.h>
+#include <tdemessagebox.h>
+#include <tdelocale.h>
 #include <kprocess.h>
 
 #include <KoDocument.h>
@@ -134,7 +134,7 @@ KoFilter::ConversionStatus KisRawImport::convert(const TQCString& from, const TQ
     m_dialog->setCursor(TQt::ArrowCursor);
     TQApplication::setOverrideCursor(TQt::ArrowCursor);
 
-    KConfig * cfg = KGlobal::config();
+    TDEConfig * cfg = TDEGlobal::config();
     cfg->setGroup("rawimport");
     
     m_page->radioGray->setChecked(cfg->readBoolEntry("gray", false));
@@ -413,7 +413,7 @@ void KisRawImport::getImageData( TQStringList arguments )
     delete m_data;
 
     kdDebug(41008) << "getImageData " << arguments.join(" ") << "\n";
-    KProcess process (this);
+    TDEProcess process (this);
     m_data = new TQByteArray(0);
 
     for (TQStringList::iterator it = arguments.begin(); it != arguments.end(); ++it) {
@@ -421,14 +421,14 @@ void KisRawImport::getImageData( TQStringList arguments )
     }
 
     process.setUseShell(true);
-    connect(&process, TQT_SIGNAL(receivedStdout(KProcess *, char *, int)), this, TQT_SLOT(slotReceivedStdout(KProcess *, char *, int)));
-    connect(&process, TQT_SIGNAL(receivedStderr(KProcess *, char *, int)), this, TQT_SLOT(slotReceivedStderr(KProcess *, char *, int)));
-    connect(&process, TQT_SIGNAL(processExited(KProcess *)), this, TQT_SLOT(slotProcessDone()));
+    connect(&process, TQT_SIGNAL(receivedStdout(TDEProcess *, char *, int)), this, TQT_SLOT(slotReceivedStdout(TDEProcess *, char *, int)));
+    connect(&process, TQT_SIGNAL(receivedStderr(TDEProcess *, char *, int)), this, TQT_SLOT(slotReceivedStderr(TDEProcess *, char *, int)));
+    connect(&process, TQT_SIGNAL(processExited(TDEProcess *)), this, TQT_SLOT(slotProcessDone()));
 
 
     kdDebug(41008) << "Starting process\n";
 
-    if (!process.start(KProcess::NotifyOnExit, KProcess::AllOutput)) {
+    if (!process.start(TDEProcess::NotifyOnExit, TDEProcess::AllOutput)) {
         KMessageBox::error( 0, i18n("Cannot convert RAW files because the dcraw executable could not be started."));
     }
     while (process.isRunning()) {
@@ -453,7 +453,7 @@ void KisRawImport::slotProcessDone()
     kdDebug(41008) << "process done!\n";
 }
 
-void KisRawImport::slotReceivedStdout(KProcess *, char *buffer, int buflen)
+void KisRawImport::slotReceivedStdout(TDEProcess *, char *buffer, int buflen)
 {
     //kdDebug(41008) << "stdout received " << buflen << " bytes on stdout.\n";
     //kdDebug(41008) << TQString::fromAscii(buffer, buflen) << "\n";
@@ -462,7 +462,7 @@ void KisRawImport::slotReceivedStdout(KProcess *, char *buffer, int buflen)
     memcpy(m_data->data() + oldSize, buffer, buflen);
 }
 
-void KisRawImport::slotReceivedStderr(KProcess *, char *buffer, int buflen)
+void KisRawImport::slotReceivedStderr(TDEProcess *, char *buffer, int buflen)
 {
     TQByteArray b(buflen);
     memcpy(b.data(), buffer, buflen);
