@@ -69,7 +69,7 @@ class KDGanttMinimizeSplitter;
 class KDGanttView : public KDGanttMinimizeSplitter
 {
     Q_OBJECT
-  TQ_OBJECT
+  
 
     TQ_PROPERTY( bool showLegend READ showLegend WRITE setShowLegend )
     TQ_PROPERTY( bool showListView READ showListView WRITE setShowListView )
@@ -101,16 +101,16 @@ class KDGanttView : public KDGanttMinimizeSplitter
     TQ_PROPERTY( bool showTimeTablePopupMenu READ showTimeTablePopupMenu WRITE setShowTimeTablePopupMenu )
     TQ_PROPERTY( bool headerVisible READ headerVisible WRITE setHeaderVisible )
     TQ_PROPERTY( bool showLegendButton READ showLegendButton	WRITE setShowLegendButton )
-    TQ_PROPERTY( bool legendIsDockwindow READ legendIsDockwindow WRITE setLegendIsDockwindow )
+    TQ_PROPERTY( bool legendIsDoctwindow READ legendIsDoctwindow WRITE setLegendIsDoctwindow )
     TQ_PROPERTY( bool displayEmptyTasksAsLine READ displayEmptyTasksAsLine WRITE setDisplayEmptyTasksAsLine )
     TQ_PROPERTY( TQBrush noInformationBrush READ noInformationBrush WRITE setNoInformationBrush )
     TQ_PROPERTY( bool dragEnabled READ dragEnabled WRITE setDragEnabled )
     TQ_PROPERTY( bool dropEnabled READ dropEnabled WRITE setDropEnabled )
     TQ_PROPERTY( bool calendarMode READ calendarMode WRITE setCalendarMode )
 
-    Q_ENUMS( Scale )
-    Q_ENUMS( YearFormat )
-    Q_ENUMS( HourFormat )
+    TQ_ENUMS( Scale )
+    TQ_ENUMS( YearFormat )
+    TQ_ENUMS( HourFormat )
 
 public:
     enum Scale { Minute, Hour, Day, Week, Month, Auto };
@@ -131,9 +131,9 @@ public:
     int ganttMaximumWidth() const;
     void setShowLegend( bool show );
     bool showLegend() const;
-    void setLegendIsDockwindow( bool dock );
-    bool legendIsDockwindow( ) const;
-    TQDockWindow* legendDockwindow( ) const;
+    void setLegendIsDoctwindow( bool dock );
+    bool legendIsDoctwindow( ) const;
+    TQDockWindow* legendDoctwindow( ) const;
     void setShowListView( bool show );
     bool showListView() const;
     void setEditorEnabled( bool enable );
