@@ -30,14 +30,14 @@
 
 class TQWidget;
 class TQWorkspace;
-class KPopupMenu;
-class KActionCollection;
-class KAction;
-class KToggleAction;
+class TDEPopupMenu;
+class TDEActionCollection;
+class TDEAction;
+class TDEToggleAction;
 class KDialogBase;
 class KTextEdit;
 class KXMLGUIClient;
-class KMainWindow;
+class TDEMainWindow;
 
 namespace KoProperty {
 	class Editor;
@@ -55,7 +55,7 @@ class WidgetLibrary;
 class ObjectTreeView;
 class Connection;
 class FormManager;
-typedef TQPtrList<KAction> ActionList;
+typedef TQPtrList<TDEAction> ActionList;
 
 //! @internal
 //static FormManager* FormManager_static = 0;
@@ -72,7 +72,7 @@ typedef TQPtrList<KAction> ActionList;
 class KFORMEDITOR_EXPORT FormManager : public TQObject
 {
 	Q_OBJECT
-  TQ_OBJECT
+  
 
 	public:
 		/*! Constructs FormManager object.
@@ -95,13 +95,13 @@ class KFORMEDITOR_EXPORT FormManager : public TQObject
 		enum Options { HideEventsInPopupMenu = 1, SkipFileActions = 2,
 			HideSignalSlotConnections = 4 }; //todo
 
-		/*! Creates all the KActions related to widget insertion, and plug them
+		/*! Creates all the TDEActions related to widget insertion, and plug them
 		  into the \a collection. \a client XML GUI client is used to call
 			lib->addCustomWidgetActions(client).
 		  These actions are automatically connected to \ref insertWidget() slot.
 		  \return a TQPtrList of the created actions.
 		 */
-		ActionList createActions(WidgetLibrary *lib, KActionCollection* collection, KXMLGUIClient *client);
+		ActionList createActions(WidgetLibrary *lib, TDEActionCollection* collection, KXMLGUIClient *client);
 
 		/*! Enables or disables actions \a name.
 		 KFD uses KPart's, action collection here.
@@ -109,7 +109,7 @@ class KFORMEDITOR_EXPORT FormManager : public TQObject
 		virtual void enableAction( const char* name, bool enable ) = 0;
 
 		/*! \return action for \a name. @see enableAction() */
-		virtual KAction* action(const char* name) = 0;
+		virtual TDEAction* action(const char* name) = 0;
 
 		bool isPasteEnabled();
 
@@ -453,7 +453,7 @@ class KFORMEDITOR_EXPORT FormManager : public TQObject
 
 		// Copy/Paste
 		TQDomDocument m_domDoc;
-		KPopupMenu *m_popup;
+		TDEPopupMenu *m_popup;
 		TQPoint m_insertPoint;
 		TQGuardedPtr<TQWidget> m_menuWidget;
 
@@ -464,11 +464,11 @@ class KFORMEDITOR_EXPORT FormManager : public TQObject
 		// Connection stuff
 		bool m_drawingSlot;
 		Connection *m_connection;
-		KPopupMenu *m_sigSlotMenu;
+		TDEPopupMenu *m_sigSlotMenu;
 
 		// Actions
-		KActionCollection *m_collection;
-		KToggleAction *m_pointer, *m_dragConnection, *m_snapToGrid;
+		TDEActionCollection *m_collection;
+		TDEToggleAction *m_pointer, *m_dragConnection, *m_snapToGrid;
 
 		//! Used to delayed widgets deletion
 		TQTimer m_deleteWidgetLater_timer;
