@@ -27,7 +27,7 @@
 
 #include <kiconloader.h>
 #include <kdebug.h>
-#include <krecentdirs.h>
+#include <tderecentdirs.h>
 
 #include <tqobjectlist.h>
 #include <tqlineedit.h>
@@ -56,7 +56,7 @@ KexiStartupFileDialogBase::KexiStartupFileDialogBase(
 	//make default 'My Documents' folder
 //TODO: store changes in the app's config file?
 	if (_dirName.isEmpty())
-		_dirName = KGlobalSettings::documentPath();
+		_dirName = TDEGlobalSettings::documentPath();
 
 	init(_dirName, filter, parent);
 
@@ -84,7 +84,7 @@ void KexiStartupFileDialogBase::init(const TQString& startDir, const TQString& f
 //TODO    d->keepLocation = false;
 //TODO    d->operationMode = Opening;
     setMode(KFile::File | KFile::ExistingOnly); //(js) default: open action
-    setIcon( KGlobal::iconLoader()->loadIcon("fileopen", KIcon::Desktop) );
+    setIcon( TDEGlobal::iconLoader()->loadIcon("document-open", TDEIcon::Desktop) );
 		setDir(TQDir(startDir));
 //TODO    d->hasDefaultFilter = false;
 //TODO    d->hasView = false;
@@ -99,15 +99,15 @@ void KexiStartupFileDialogBase::init(const TQString& startDir, const TQString& f
 //(js)    d->autoSelectExtCheckBox = 0; // delayed loading
 //TODO    d->autoSelectExtChecked = false;
 //(js)    d->urlBar = 0; // delayed loading
-//TODO    KConfig *config = KGlobal::config();
-//TODO    KConfigGroupSaver cs( config, ConfigGroup );
+//TODO    TDEConfig *config = TDEGlobal::config();
+//TODO    TDEConfigGroupSaver cs( config, ConfigGroup );
 //TODO    d->initializeSpeedbar = config->readBoolEntry( "Set speedbar defaults",
 //TODO                                                   true );
 //TODO    d->completionLock = false;
 
 //TODO    TQtMsgHandler oldHandler = tqInstallMsgHandler( silenceTQToolBar );
 //TODO    toolbar = 0; //(js)
-//(js)    toolbar = new KToolBar( d->mainWidget, "KFileDialog::toolbar", true);
+//(js)    toolbar = new TDEToolBar( d->mainWidget, "KFileDialog::toolbar", true);
 //(js)    toolbar->setFlat(true);
 //TODO    tqInstallMsgHandler( oldHandler );
 
@@ -122,27 +122,27 @@ void KexiStartupFileDialogBase::init(const TQString& startDir, const TQString& f
     u.setPath( TQDir::rootDirPath() );
     TQString text = i18n("Root Directory: %1").arg( u.path() );
     d->pathCombo->addDefaultURL( u,
-                                 KMimeType::pixmapForURL( u, 0, KIcon::Small ),
+                                 KMimeType::pixmapForURL( u, 0, TDEIcon::Small ),
                                  text );
 
     u.setPath( TQDir::homeDirPath() );
     text = i18n("Home Directory: %1").arg( u.path( +1 ) );
-    d->pathCombo->addDefaultURL( u, KMimeType::pixmapForURL( u, 0, KIcon::Small ),
+    d->pathCombo->addDefaultURL( u, KMimeType::pixmapForURL( u, 0, TDEIcon::Small ),
                                  text );
 
     KURL docPath;
-    docPath.setPath( KGlobalSettings::documentPath() );
+    docPath.setPath( TDEGlobalSettings::documentPath() );
     if ( u.path(+1) != docPath.path(+1) ) {
         text = i18n("Documents: %1").arg( docPath.path( +1 ) );
         d->pathCombo->addDefaultURL( u,
-                                     KMimeType::pixmapForURL( u, 0, KIcon::Small ),
+                                     KMimeType::pixmapForURL( u, 0, TDEIcon::Small ),
                                      text );
     }
 
-    u.setPath( KGlobalSettings::desktopPath() );
+    u.setPath( TDEGlobalSettings::desktopPath() );
     text = i18n("Desktop: %1").arg( u.path( +1 ) );
     d->pathCombo->addDefaultURL( u,
-                                 KMimeType::pixmapForURL( u, 0, KIcon::Small ),
+                                 KMimeType::pixmapForURL( u, 0, TDEIcon::Small ),
                                  text );
 
     u.setPath( "/tmp" );
@@ -179,7 +179,7 @@ void KexiStartupFileDialogBase::init(const TQString& startDir, const TQString& f
     ops->setupMenu(KDirOperator::SortActions |
                    KDirOperator::FileActions |
                    KDirOperator::ViewActions);
-    KActionCollection *coll = ops->actionCollection();
+    TDEActionCollection *coll = ops->actionCollection();
 
     // plug nav items into the toolbar
     coll->action( "up" )->plug( toolbar );
@@ -207,16 +207,16 @@ void KexiStartupFileDialogBase::init(const TQString& startDir, const TQString& f
                          "Click on this button to open the bookmark menu where you may add, "
                          "edit or select a bookmark.<p>"
                          "These bookmarks are specific to the file dialog, but otherwise operate "
-                         "like bookmarks elsewhere in KDE.</qt>"));
+                         "like bookmarks elsewhere in TDE.</qt>"));
     connect( d->bookmarkHandler, TQT_SIGNAL( openURL( const TQString& )),
              TQT_SLOT( enterURL( const TQString& )));
 
-    KToggleAction *showSidebarAction =
-        new KToggleAction(i18n("Show Quick Access Navigation Panel"), Key_F9, coll,"toggleSpeedbar");
+    TDEToggleAction *showSidebarAction =
+        new TDEToggleAction(i18n("Show Quick Access Navigation Panel"), Key_F9, coll,"toggleSpeedbar");
     connect( showSidebarAction, TQT_SIGNAL( toggled( bool ) ),
              TQT_SLOT( toggleSpeedbar( bool )) );
 
-    KActionMenu *menu = new KActionMenu( i18n("Configure"), "configure", this, "extra menu" );
+    TDEActionMenu *menu = new TDEActionMenu( i18n("Configure"), "configure", this, "extra menu" );
     menu->setWhatsThis(i18n("<qt>This is the configuration menu for the file dialog. "
                             "Various options can be accessed from this menu including: <ul>"
                             "<li>how files are sorted in the list</li>"
@@ -257,8 +257,8 @@ void KexiStartupFileDialogBase::init(const TQString& startDir, const TQString& f
 
 
     toolbar->setItemAutoSized (PATH_COMBO);
-    toolbar->setIconText(KToolBar::IconOnly);
-    toolbar->setBarPos(KToolBar::Top);
+    toolbar->setIconText(TDEToolBar::IconOnly);
+    toolbar->setBarPos(TDEToolBar::Top);
     toolbar->setMovingEnabled(false);
     toolbar->adjustSize();
 
@@ -272,8 +272,8 @@ void KexiStartupFileDialogBase::init(const TQString& startDir, const TQString& f
              TQT_SLOT( pathComboChanged( const TQString& ) ));
     connect( d->pathCombo, TQT_SIGNAL( completion( const TQString& )),
              TQT_SLOT( dirCompletion( const TQString& )));
-    connect( d->pathCombo, TQT_SIGNAL( textRotation(KCompletionBase::KeyBindingType) ),
-             d->pathCombo, TQT_SLOT( rotateText(KCompletionBase::KeyBindingType) ));
+    connect( d->pathCombo, TQT_SIGNAL( textRotation(TDECompletionBase::KeyBindingType) ),
+             d->pathCombo, TQT_SLOT( rotateText(TDECompletionBase::KeyBindingType) ));
 
     TQString whatsThisText;
 
@@ -299,8 +299,8 @@ void KexiStartupFileDialogBase::init(const TQString& startDir, const TQString& f
             this,  TQT_SLOT( locationActivated( const TQString& ) ));
     connect( locationEdit, TQT_SIGNAL( completion( const TQString& )),
              TQT_SLOT( fileCompletion( const TQString& )));
-    connect( locationEdit, TQT_SIGNAL( textRotation(KCompletionBase::KeyBindingType) ),
-             locationEdit, TQT_SLOT( rotateText(KCompletionBase::KeyBindingType) ));
+    connect( locationEdit, TQT_SIGNAL( textRotation(TDECompletionBase::KeyBindingType) ),
+             locationEdit, TQT_SLOT( rotateText(TDECompletionBase::KeyBindingType) ));
 
     // the Filter label/edit
     whatsThisText = i18n("<qt>This is the filter to apply to the file list. "
@@ -387,7 +387,7 @@ void KexiStartupFileDialogBase::setOperationMode( KFileDialog::OperationMode mod
   //  d->keepLocation = (mode == Saving);
     if (mode == KFileDialog::Saving) {
       setMode( KFile::File );
-      setIcon( KGlobal::iconLoader()->loadIcon("filesave", KIcon::Desktop) );
+      setIcon( TDEGlobal::iconLoader()->loadIcon("document-save", TDEIcon::Desktop) );
     }
 //(js)    filterWidget->setEditable( !d->hasDefaultFilter || mode != Saving );
 //(js)    d->okButton->setGuiItem( (mode == Saving) ? KStdGuiItem::save() : KStdGuiItem::ok() );
@@ -399,9 +399,9 @@ TQString KexiStartupFileDialogBase::currentFilter() const
 {
 	//(js)filterWidget->currentFilter();
 
-	//we need to convert TQt filter format to KDE format
+	//we need to convert TQt filter format to TDE format
 	//TQt format: "some text (*.first *.second)" or "All (*)"
-	//KDE format: "*.first *.second" or "*"
+	//TDE format: "*.first *.second" or "*"
 	TQString f = selectedFilter();
 	if (f.find('(')!=-1)
 		f = f.mid(f.find('(')+1);
@@ -471,6 +471,6 @@ void KexiStartupFileDialogBase::saveLastVisitedPath(const TQString& path)
 		TQFileInfo fi(path);
 		TQString dir( fi.isDir() ? fi.absFilePath() : fi.dir(true).absPath() );
 		if (!dir.isEmpty())
-			KRecentDirs::add(m_lastVisitedPathsVariable, dir);
+			TDERecentDirs::add(m_lastVisitedPathsVariable, dir);
 	}
 }
