@@ -30,11 +30,11 @@
 #include <tqlineedit.h>
 #include <tqpopupmenu.h>
 
-#include <klocale.h>
-#include <kaction.h>
-#include <kpopupmenu.h>
-#include <kglobalsettings.h>
-#include <kmessagebox.h>
+#include <tdelocale.h>
+#include <tdeaction.h>
+#include <tdepopupmenu.h>
+#include <tdeglobalsettings.h>
+#include <tdemessagebox.h>
 
 #include <kexidb/tableschema.h>
 #include <kexidb/indexschema.h>
@@ -62,22 +62,22 @@ KexiRelationView::KexiRelationView(TQWidget *parent, const char *name)
 	setResizePolicy(Manual);
 /*MOVED TO KexiRelationDialog
 	//actions
-	m_tableQueryPopup = new KPopupMenu(this, "m_popup");
+	m_tableQueryPopup = new TDEPopupMenu(this, "m_popup");
 	m_tableQueryPopup->insertTitle(i18n("Table"));
-	m_connectionPopup = new KPopupMenu(this, "m_connectionPopup");
+	m_connectionPopup = new TDEPopupMenu(this, "m_connectionPopup");
 	m_connectionPopup->insertTitle(i18n("Relation"));
-	m_areaPopup = new KPopupMenu(this, "m_areaPopup");
+	m_areaPopup = new TDEPopupMenu(this, "m_areaPopup");
 	
 	plugSharedAction("edit_delete", i18n("Hide Table"), m_tableQueryPopup);
 	plugSharedAction("edit_delete",m_connectionPopup);
 	plugSharedAction("edit_delete",this, TQT_SLOT(removeSelectedObject()));
 */	
 #if 0
-	m_removeSelectedTableQueryAction = new KAction(i18n("&Hide Selected Table/Query"), "editdelete", "",
+	m_removeSelectedTableQueryAction = new TDEAction(i18n("&Hide Selected Table/Query"), "edit-delete", "",
 		this, TQT_SLOT(removeSelectedTableQuery()), parent->actionCollection(), "relationsview_removeSelectedTableQuery");
-	m_removeSelectedConnectionAction = new KAction(i18n("&Remove Selected Relationship"), "button_cancel", "",
+	m_removeSelectedConnectionAction = new TDEAction(i18n("&Remove Selected Relationship"), "button_cancel", "",
 		this, TQT_SLOT(removeSelectedConnection()), parent->actionCollection(), "relationsview_removeSelectedConnection");
-	m_openSelectedTableQueryAction = new KAction(i18n("&Open Selected Table/Query"), "", "",
+	m_openSelectedTableQueryAction = new TDEAction(i18n("&Open Selected Table/Query"), "", "",
 		this, TQT_SLOT(openSelectedTableQuery()), 0/*parent->actionCollection()*/, "relationsview_openSelectedTableQuery");
 #endif
 
@@ -86,7 +86,7 @@ KexiRelationView::KexiRelationView(TQWidget *parent, const char *name)
 #if 0
 
 
-	m_popup = new KPopupMenu(this, "m_popup");
+	m_popup = new TDEPopupMenu(this, "m_popup");
 	m_openSelectedTableQueryAction->plug( m_popup );
 	m_removeSelectedTableQueryAction->plug( m_popup );
 	m_removeSelectedConnectionAction->plug( m_popup );
@@ -430,7 +430,7 @@ KexiRelationView::keyPressEvent(TQKeyEvent *ev)
 {
 	kdDebug() << "KexiRelationView::keyPressEvent()" << endl;
 
-	if (ev->key()==KGlobalSettings::contextMenuKey()) {
+	if (ev->key()==TDEGlobalSettings::contextMenuKey()) {
 		if (m_selectedConnection) {
 			emit connectionContextMenuRequest(
 				mapToGlobal(m_selectedConnection->connectionRect().center()) );
