@@ -236,7 +236,7 @@ public:
 	//! single shot after 1ms for contents updatinh
 	void triggerUpdate();
 
-	typedef enum ScrollDirection
+	enum ScrollDirection
 	{
 		ScrollUp,
 		ScrollDown,
