@@ -2,29 +2,29 @@
 #define KFORMULA_FACTORY_H
 
 #include <KoFactory.h>
-//#include <kaboutdata.h>
+//#include <tdeaboutdata.h>
 
-class KInstance;
-class KInstance;
-class KAboutData;
+class TDEInstance;
+class TDEInstance;
+class TDEAboutData;
 
 class KFormulaFactory : public KoFactory
 {
     Q_OBJECT
-  TQ_OBJECT
+  
 public:
     KFormulaFactory( TQObject* parent = 0, const char* name = 0 );
     ~KFormulaFactory();
 
     virtual KParts::Part *createPartObject( TQWidget *parentWidget = 0, const char *widgetName = 0, TQObject *parent = 0, const char *name = 0, const char *classname = "KoDocument", const TQStringList &args = TQStringList() );
 
-    static KInstance* global();
+    static TDEInstance* global();
 
-    static KAboutData* aboutData();
+    static TDEAboutData* aboutData();
 
 private:
-    static KInstance* s_global;
-    static KAboutData* s_aboutData;
+    static TDEInstance* s_global;
+    static TDEAboutData* s_aboutData;
 };
 
 #endif
