@@ -24,11 +24,11 @@
 #include "kptcommand.h"
 
 #include <kdebug.h>
-#include <klistview.h>
-#include <kmessagebox.h>
-#include <klocale.h>
-#include <kabc/addressee.h>
-#include <kabc/addresseedialog.h>
+#include <tdelistview.h>
+#include <tdemessagebox.h>
+#include <tdelocale.h>
+#include <tdeabc/addressee.h>
+#include <tdeabc/addresseedialog.h>
 
 #include <tqgroupbox.h>
 #include <tqheader.h>
@@ -180,10 +180,10 @@ public:
     int m_state;
 };
 
-class ResourcesPanelGroupLVItem : public KListViewItem {
+class ResourcesPanelGroupLVItem : public TDEListViewItem {
 public:
-    ResourcesPanelGroupLVItem(ResourcesPanel &pan, KListView *lv, GroupItem *item)
-    :  KListViewItem(lv, item->m_name),
+    ResourcesPanelGroupLVItem(ResourcesPanel &pan, TDEListView *lv, GroupItem *item)
+    :  TDEListViewItem(lv, item->m_name),
        m_group(item),
        panel(pan) {
         
@@ -218,7 +218,7 @@ protected:
             return;
         }
         panel.renameStopped(this);
-        KListViewItem::cancelRename(col);
+        TDEListViewItem::cancelRename(col);
         setRenameEnabled(col, false);
     }
 };
