@@ -28,7 +28,7 @@
 #include <tqstring.h>
 #include <tqstringlist.h>
 
-#include <klocale.h>
+#include <tdelocale.h>
 #include <kdebug.h>
 
 namespace KPlato
