@@ -30,8 +30,8 @@
 #include "KPrCanvas.h"
 #include "KPrPage.h"
 
-#include <kio/netaccess.h>
-#include <ktempfile.h>
+#include <tdeio/netaccess.h>
+#include <tdetempfile.h>
 
 #include <tqdir.h>
 #include <tqframe.h>
@@ -45,14 +45,14 @@
 #include <tqvbox.h>
 #include <tqwhatsthis.h>
 
-#include <kapplication.h>
+#include <tdeapplication.h>
 #include <kbuttonbox.h>
 #include <kcolorbutton.h>
-#include <kglobal.h>
-#include <kglobalsettings.h>
+#include <tdeglobal.h>
+#include <tdeglobalsettings.h>
 #include <klineedit.h>
-#include <klocale.h>
-#include <kmessagebox.h>
+#include <tdelocale.h>
+#include <tdemessagebox.h>
 #include <kprogress.h>
 #include <kstandarddirs.h>
 #include <kurlrequester.h>
@@ -84,7 +84,7 @@ void KPrMSPresentation::initCreation( KProgress *progressBar )
     // we create the DCIM file, and then iterate through looking
     // for the next "available" directory slot
     KURL str(  path + "/DCIM"  );
-    KIO::NetAccess::mkdir( str,( TQWidget* )0L  );
+    TDEIO::NetAccess::mkdir( str,( TQWidget* )0L  );
 
     p = progressBar->progress();
     progressBar->setProgress( ++p );
@@ -92,7 +92,7 @@ void KPrMSPresentation::initCreation( KProgress *progressBar )
 
     for (int dirNum = 101; dirNum < 999; dirNum++) {
         slidePath = TQString("/DCIM/%1MSPJP").arg(dirNum);
-        if (! KIO::NetAccess::exists(( path + slidePath), true, ( TQWidget* )0L) )
+        if (! TDEIO::NetAccess::exists(( path + slidePath), true, ( TQWidget* )0L) )
             break;
     }
 
@@ -101,20 +101,20 @@ void KPrMSPresentation::initCreation( KProgress *progressBar )
     kapp->processEvents();
 
     str = (  path + slidePath );
-    KIO::NetAccess::mkdir( str,( TQWidget* )0L  );
+    TDEIO::NetAccess::mkdir( str,( TQWidget* )0L  );
     p = progressBar->progress();
     progressBar->setProgress( ++p );
     kapp->processEvents();
 
     // now do the SPP file directory
     str = (  path + "/MSSONY" );
-    KIO::NetAccess::mkdir( str,( TQWidget* )0L  );
+    TDEIO::NetAccess::mkdir( str,( TQWidget* )0L  );
 
     p = progressBar->progress();
     progressBar->setProgress( ++p );
     kapp->processEvents();
     str = (  path + "/MSSONY/PJ" );
-    KIO::NetAccess::mkdir( str,( TQWidget* )0L  );
+    TDEIO::NetAccess::mkdir( str,( TQWidget* )0L  );
 
 
     p = progressBar->progress();
@@ -130,7 +130,7 @@ void KPrMSPresentation::initCreation( KProgress *progressBar )
     KTempFile tmp;
     TQString filename = path + slidePath + "/SPJT0002.JPG";
     titleSlide.save( tmp.name(), "JPEG" );
-    KIO::NetAccess::file_move( tmp.name(), filename, -1, true /*overwrite*/);
+    TDEIO::NetAccess::file_move( tmp.name(), filename, -1, true /*overwrite*/);
 
     p = progressBar->progress();
     progressBar->setProgress( ++p );
@@ -145,7 +145,7 @@ void KPrMSPresentation::initCreation( KProgress *progressBar )
 
     KTempFile tmp2;
     titleSlide.save( tmp2.name(), "JPEG" );
-    KIO::NetAccess::file_move( tmp2.name(), filename, -1, true /*overwrite*/);
+    TDEIO::NetAccess::file_move( tmp2.name(), filename, -1, true /*overwrite*/);
 
     p = progressBar->progress();
     progressBar->setProgress( ++p );
@@ -168,7 +168,7 @@ void KPrMSPresentation::createSlidesPictures( KProgress *progressBar )
         view->getCanvas()->exportPage( pgNum, 1023, 767,
                                        tmp.name(), "JPEG" );
 
-        KIO::NetAccess::file_move( tmp.name(), ( path + slidePath + filename ), -1, true /*overwrite*/);
+        TDEIO::NetAccess::file_move( tmp.name(), ( path + slidePath + filename ), -1, true /*overwrite*/);
 
         p = progressBar->progress();
         progressBar->setProgress( ++p );
@@ -266,7 +266,7 @@ void KPrMSPresentation::createIndexFile( KProgress *progressBar )
     kapp->processEvents();
 
     sppFile.close();
-    KIO::NetAccess::file_move( sppFile.name(), filenameStore, -1, true /*overwrite*/);
+    TDEIO::NetAccess::file_move( sppFile.name(), filenameStore, -1, true /*overwrite*/);
 }
 
 void KPrMSPresentation::init()
@@ -287,7 +287,7 @@ void KPrMSPresentation::init()
     backColour = TQt::black;
     textColour = TQt::white;
 
-    path = KGlobalSettings::documentPath();
+    path = TDEGlobalSettings::documentPath();
 }
 
 KPrMSPresentationSetup::KPrMSPresentationSetup( KPrDocument *_doc, KPrView *_view )
@@ -441,7 +441,7 @@ void KPrMSPresentationSetup::finish()
     TQString pathname = path->lineEdit()->text();
 
     // path doesn't exist. ask user if it should be created.
-    if ( !KIO::NetAccess::exists(pathname, false, this) ) {
+    if ( !TDEIO::NetAccess::exists(pathname, false, this) ) {
         TQString msg = i18n( "<qt>The directory <b>%1</b> does not exist.<br>"
                             "Do you want create it?</qt>" );
         if( KMessageBox::questionYesNo( this, msg.arg( pathname ),
@@ -450,7 +450,7 @@ void KPrMSPresentationSetup::finish()
             {
                 // we are trying to create the directory
                 TQDir dir;
-                bool ok = KIO::NetAccess::mkdir( pathname,this );
+                bool ok = TDEIO::NetAccess::mkdir( pathname,this );
                 if( !ok ) {
                     // then directory couldn't be created
                     KMessageBox::sorry( this,
@@ -467,7 +467,7 @@ void KPrMSPresentationSetup::finish()
     }
 
     TQString sppFile( pathname + "/MSSONY/PJ/" + title->text() + ".SPP" );
-    if (KIO::NetAccess::exists(sppFile, false, this ) ) {
+    if (TDEIO::NetAccess::exists(sppFile, false, this ) ) {
         if ( KMessageBox::warningYesNo( 0,
                                    i18n( "You are about to overwrite an existing index "
                                          "file : %1.\n "
