@@ -25,8 +25,8 @@
 
 void KoPointArray::translate( double dx, double dy )
 {
-    register KoPoint *p = data();
-    register int i = size();
+    KoPoint *p = data();
+    int i = size();
     KoPoint pt( dx, dy );
     while ( i-- ) {
         *p += pt;
@@ -232,7 +232,7 @@ KoRect KoPointArray::boundingRect() const
 {
     if ( isEmpty() )
         return KoRect( 0, 0, 0, 0 );        // null rectangle
-    register KoPoint *pd = data();
+    KoPoint *pd = data();
     double minx, maxx, miny, maxy;
     minx = maxx = pd->x();
     miny = maxy = pd->y();
