@@ -25,8 +25,8 @@
 #include <tqpainter.h>
 #include <tqpixmap.h>
 
-#include <klocale.h>
-#include <kpopupmenu.h>
+#include <tdelocale.h>
+#include <tdepopupmenu.h>
 
 #include <KoDocument.h>
 #include <KoPoint.h>
@@ -36,7 +36,7 @@
 
 #include "KoGuideLineDia.h"
 
-class KoGuides::Popup : public KPopupMenu
+class KoGuides::Popup : public TDEPopupMenu
 {
 public: 
     Popup( KoGuides * guides )
